@@ -16,7 +16,7 @@
 #'   unnamed an error is raised.
 #'
 #' @export
-#' 
+#'
 #' @import digest tibble
 #'
 #' @seealso \code{\link{create.project}}, \code{\link{get.project}},
@@ -351,15 +351,21 @@ load.project <- function(...)
     if("munge_files" %in% names(config$.override.config)){
       munge.files <- paste0(config$.override.config[["munge_files"]], collapse="|")
     } else{
-      munge.files <- '[.][rR]$'
+      munge.files <- '[.][rR]|[.][pP][yY]$' # Add .py files
     }
     return(munge.files)
   }
-
   for (preprocessing.script in sort(dir(dir_name, pattern = munge_files())))
   {
     message(' Running preprocessing script: ', preprocessing.script)
-    source(file.path(dir_name, preprocessing.script), local = .TargetEnv)
+    # Check for Python extension using tolower() for case-insensitivity
+    if (tolower(tools::file_ext(preprocessing.script)) == "py") {
+      message(' Sourcing Python script: ', preprocessing.script)
+      reticulate::source_python(file.path(dir_name, preprocessing.script))
+    } else {
+      message(' Sourcing R script: ', preprocessing.script)
+      source(file.path(dir_name, preprocessing.script), local = .TargetEnv)
+    }
   }
   return(my.project.info)
 }
